

var margin = { top: 10, right: 10, bottom: 10, left: 10 },
    width = 1200 - margin.left - margin.right,
    height = 740 - margin.top - margin.bottom;

var formatNumber = d3.format(",.4f"), // zero decimal places
    format = function (d) { return formatNumber(d); },
    color = d3.scale.category20();

var svg, sankey, path;

function loadData() {
    $("#chart").html("");
    // append the svg canvas to the page
    svg = d3.select("#chart").append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom)
        .append("g")
        .attr("transform",
            "translate(" + margin.left + "," + margin.top + ")");
    
    // Set the sankey diagram properties
    sankey = d3.sankey()
        .nodeWidth(36)
        .nodePadding(10)
        .size([width, height]);
    
    path = sankey.link();

    // load the data
    d3.json("Json", function (error, data) {
        var graph = JSON.parse(data);
        var nodeMap = {};
        graph.nodes.forEach(function (x) { nodeMap[x.name] = x; });
        graph.links = graph.links.map(function (x) {
            return {
                source: nodeMap[x.source],
                target: nodeMap[x.target],
                value: x.value
            };
        });
        
        sankey
            .nodes(graph.nodes)
            .links(graph.links)
            .layout(32);
        
        // add in the links
        var link = svg.append("g").selectAll(".link")
            .data(graph.links)
            .enter().append("path")
            .attr("class", "link")
            .attr("d", path)
            .style("stroke-width", function (d) { return Math.max(1, d.dy); })
            .sort(function (a, b) { return b.dy - a.dy; });
        
        // add the link titles
        link.append("title")
            .text(function (d) {
            return d.source.name + " -> " +
                    d.target.name + "\n" + format(d.value) + " MB/s";
        });
        
        // add in the nodes
        var node = svg.append("g").selectAll(".node")
            .data(graph.nodes)
            .enter().append("g")
            .attr("class", "node")
            .attr("transform", function (d) {
            return "translate(" + d.x + "," + d.y + ")";
        })
            .call(d3.behavior.drag()
                .origin(function (d) { return d; })
                .on("dragstart", function () {
            this.parentNode.appendChild(this);
        })
                .on("drag", dragmove));
        
        // add the rectangles for the nodes
        node.append("rect")
            .attr("height", function (d) { return d.dy; })
            .attr("width", function (d) { return d.dx; })
            .style("fill", function (d) {
            return d.color = color(d.name.replace(/\..*/, ""));
        })
            .style("stroke", function (d) {
            return d3.rgb(d.color).darker(2);
        })
            .append("title")
            .text(function (d) {
            return d.name + "\n" + format(d.repvalue) + " " + d.unit;
        });
        
        
        // add in the title for the nodes
        node.append("text")
            .attr("x", -6)
            .attr("y", function (d) { return d.dy / 2; })
            .attr("dy", 16)
            .attr("text-anchor", "end")
            .attr("transform", null)
            .text(function (d) { return d.name; })
            .filter(function (d) { return d.x < width / 2; })
            .attr("x", 6 + sankey.nodeWidth())
            .attr("text-anchor", "start");
        
            node.append("text")
            .attr("x", -6)
            .attr("y", function (d) { return (d.dy / 2) + 18; })
            .attr("dy",16)
            .attr("text-anchor", "end")
            .attr("transform", null)
            .text(function (d) { return "Last Update: " + ((Date.now() - d.lastUpdate)/1000).toFixed(2) + " s ago"; })
            .filter(function (d) { return d.x < width / 2; })
            .attr("x", 6 + sankey.nodeWidth())
            .attr("text-anchor", "start");
        
        // the function for moving the nodes
        function dragmove(d) {
            d3.select(this).attr("transform",
                "translate(" + (
                    d.x //= Math.max(0, Math.min(width - d.dx, d3.event.x))
) + "," + (
                    d.y = Math.max(0, Math.min(height - d.dy, d3.event.y))
) + ")");
            sankey.relayout();
            link.attr("d", path);
        }
    });
}

$( document ).ready(function() {
    loadData();
   //setInterval(loadData, 1000);

});